%DRIVER demo driver for lbdtik.m
%
%   just edit the parameters and run the program

%	Giuseppe Rodriguez,  10-09-09
%	Email: rodriguez@unica.it

m = 200;  n = 200;	% size of matrix
noise = 1e-2;		% noise level

[A rhs xtrue] = baart(max(m,n));   % baart matrix from Regularization Tools
A = A(1:m,1:n);

randn('seed',0);	% add noise
noisev = randn(m,1);
b = rhs + noise * norm(rhs) * noisev/norm(noisev);

estype = 2;		% estimate type
kmax = 100;		% max number of Lanczos iterations
reorth = 1;		% reorthogonalization on

%debug = .1;		% for intermediate results & pictures
debug = 0;		% for a clean run

[xlam,lamopt,k,eta,lamv] = lbdtik(A,b,estype,[],kmax,reorth,[],debug);

[U s V] = csvd(A);
lammin = round(log10(lamv(1)));
lammax = round(log10(lamv(end)));
lamvec = 10.^([0:100]'/100*(lammax-lammin)+lammin);
X = tikhonov(U,s,V,b,lamvec);
nmu = size(X,2);
errtik = zeros(nmu,1);
for i=1:nmu
	errtik(i) = norm(X(:,i)-xtrue);
end

figure(52)
loglog(lamv,eta,'-o','color',[0 .5 0])
set(gca,'fontsize',12)
hold on
hh = loglog(lamvec,errtik,'b');
set(hh,'linewidth',2)
hold off
title('Comparison of error and lbdtik estimate')
legend('\eta_2','error')

figure(2)
set(gca,'fontsize',12)
[mm kk] = min(errtik);
hh = plot([xtrue,xlam,X(:,kk)]);
title('Comparison of true and lbdtik solutions')
set(hh(1),'linewidth',2)
set(hh(1),'color',[0 .5 0])
set(hh(2),'color','b')
set(hh(3),'linestyle','--')

